from typing import List, Tuple

class SpecialWordReplacer:
    """
    This class replace or mask special words between in particular words in a text.

    :param special_words: List of special words to replace or mask
    :param target_word: Word to replace or mask in special words
    :param replacement_char: Character to replace the target word with

    >>> replacer = SpecialWordReplacer(['New York', 'El Nino'], ' ', '•')
    >>> print(replacer.mask_words('New York is affected by El Nino.'))
    New•York is affected by El•Nino.
    >>> replacer = SpecialWordReplacer(['"apple"'], 'apple', 'green apple')
    >>> print(replacer.mask_words('He said the word "apple" while pointing at an apple.'))
    He said the word "green apple" while pointing at an apple.
    """
    def __init__(self, special_words: List[str], target_word: str, replacement_char: str):
        import re

        self.special_words = special_words
        self.target_word = target_word
        self.replacement_char = replacement_char
        self.compiled_patterns = {
            re.compile(re.escape(word)): word.replace(target_word, replacement_char)
            for word in special_words
        }

    def mask_words(self, text: str) -> str:
        """
        This function masks special words in a text.

        :param text: Text to mask special words in

        :return: Text with special words masked
        """
        for pattern, masked_word in self.compiled_patterns.items():
            text = pattern.sub(masked_word, text)
        return text
    
    def __repr__(self):
        return f'<SpecialWordReplacer(special_words={self.special_words}, target_word=\'{self.target_word}\', replacement_char=\'{self.replacement_char}\')>'



from typing import List


def find_with_word(word: str, sentences: List[str]) -> List[str]:
    """
    This function checks if a word is in a list of sentences.

    :param word: Word to check
    :param sentences: List of sentences
    
    :return: List of sentences that contain the word

    >>> print(find_with_word('experience', [
    ...     'Proverbs are short sentences drawn from long experience.', 
    ...     'Naked I came into the world, and naked I must go out.']))
    ['Proverbs are short sentences drawn from long experience.']
    """
    return [sentence for sentence in sentences if word in sentence]


def replace_word(word: str, new_word: str, sentences: List[str]) -> List[str]:
    """
    This function replaces a word with a new word in a list of sentences.

    :param word: Word to replace
    :param new_word: New word to replace with
    :param sentences: List of sentences
    
    :return: List of sentences with the replaced word

    >>> print(replace_word('experience', 'wisdom', [
    ...     'Proverbs are short sentences drawn from long experience.', 
    ...     'Naked I came into the world, and naked I must go out.']))
    ['Proverbs are short sentences drawn from long wisdom.']
    """
    return [sentence.replace(word, new_word) for sentence in sentences]
